select :group_type*: as group_type, server_id as server_id, group_id as group_id, name as name from :table*: where server_id=:dest_server_id: or (server_id=:src_server_id: and type=:src_type*:) [[[union select :group_type*: as group_type, server_id as server_id, group_id as group_id, name as name from :table*: where :dest_server_id: or (server_id=:src_server_id: and type=:src_type*:)]]]