INSERT INTO bans 
(server_id,
 ban_ip,
 ban_name,
 ban_uid,
 ban_timestamp,
 ban_length,
 ban_invoker_client_id,
 ban_invoker_uid,
 ban_invoker_name,
 ban_reason,
 ban_hash) 
VALUES
(:server_id:,
 :ban_ip:,
 :ban_name:,
 :ban_uid:,
 :ban_timestamp:,
 :ban_length:,
 :ban_invoker_client_id:,
 :ban_invoker_uid:,
 :ban_invoker_name:,
 :ban_reason:,
 :ban_hash:);