delete from group_server_to_client where id1 in (select client_id from clients where server_id = :server_id:);
delete from servers where server_id = :server_id:;
delete from server_properties where id = :server_id:;
delete from perm_channel where server_id = :server_id:;
delete from perm_channel_clients where server_id = :server_id:;
delete from perm_channel_groups where server_id = :server_id:;
delete from perm_client where server_id = :server_id:;
delete from perm_server_group where server_id = :server_id:;
delete from group_channel_to_client where server_id = :server_id:;
delete from group_server_to_client where server_id = :server_id:;
delete from groups_channel where server_id = :server_id:;
delete from groups_server where server_id = :server_id:;
delete from messages where server_id = :server_id:;
delete from complains where server_id = :server_id:;
delete from clients where server_id = :server_id:;
delete from client_properties where server_id = :server_id:;
delete from channels where server_id = :server_id:;
delete from channel_properties where server_id = :server_id:;
delete from bans where server_id = :server_id:;
delete from tokens where server_id = :server_id:;
delete from custom_fields where server_id = :server_id:;