update perm_server_group set perm_value = 20 where perm_id = 'i_group_auto_update_type' and perm_value = 0;
update perm_server_group set perm_value = 50 where perm_id = 'i_group_auto_update_type' and perm_value = 1;
update perm_server_group set perm_value = 45 where perm_id = 'i_group_auto_update_type' and perm_value = 2;
update perm_server_group set perm_value = 30 where perm_id = 'i_group_auto_update_type' and perm_value = 3;
update perm_server_group set perm_value = 15 where perm_id = 'i_group_auto_update_type' and perm_value = 4;
update perm_channel_groups set perm_value = 40 where perm_id = 'i_group_auto_update_type' and perm_value = 5;
update perm_channel_groups set perm_value = 35 where perm_id = 'i_group_auto_update_type' and perm_value = 6;
update perm_channel_groups set perm_value = 25 where perm_id = 'i_group_auto_update_type' and perm_value = 7;
update perm_channel_groups set perm_value = 10 where perm_id = 'i_group_auto_update_type' and perm_value = 8;