DROP TABLE IF EXISTS channel_properties;
DROP INDEX IF EXISTS index_channel_properties;
DROP TABLE IF EXISTS channels;
DROP INDEX IF EXISTS index_channels;
DROP TABLE IF EXISTS client_properties;
DROP INDEX IF EXISTS index_client_properties;
DROP TABLE IF EXISTS clients;
DROP INDEX IF EXISTS index_clients;
DROP TABLE IF EXISTS groups_channel;
DROP TABLE IF EXISTS groups_server;
DROP TABLE IF EXISTS group_server_to_client;
DROP TABLE IF EXISTS group_channel_to_client;
DROP TABLE IF EXISTS perm_channel;
DROP TABLE IF EXISTS perm_channel_clients;
DROP TABLE IF EXISTS perm_channel_groups;
DROP TABLE IF EXISTS perm_client;
DROP TABLE IF EXISTS perm_server_group;
DROP TABLE IF EXISTS bindings;
DROP TABLE IF EXISTS server_properties;
DROP INDEX IF EXISTS index_server_properties;
DROP TABLE IF EXISTS servers;
DROP INDEX IF EXISTS index_servers;
DROP TABLE IF EXISTS tokens;
DROP TABLE IF EXISTS messages;
DROP TABLE IF EXISTS complains;
DROP TABLE IF EXISTS bans;
DROP TABLE IF EXISTS instance_properties;
DROP TABLE IF EXISTS custom_fields;
