insert into complains (server_id, complain_from_client_id, complain_to_client_id, complain_message, complain_timestamp, complain_hash) values (:server_id:, :complain_from_client_id:, :complain_to_client_id:, :complain_message:, :complain_timestamp:, :complain_hash:);